% Quokka3 settingsfile for calibrating the optics of an ISE HJT cell
% (c) 2021, Andreas Fell

% Reflection was measured including fingers, therefore a metal correction is applied
% The front and rear internal optical parameters are fitted to R+EQE using the optimizer funcionality

Syntax = 'generic';

Domain.DeviceType = 'semiconductor device';
Domain.Dimensions = 1;
Domain.Wz = 166;

Solver.SolutionType = 'RAT';

Thermal.T = 25 degC;

Optical.GenerationModelType = 'Text-Z';
Optical.FrontIllumination.Enable = 1;
Optical.FrontIllumination.Spectrum.Type = 'AM1.5g';
Optical.FrontIllumination.Scale = 1;
Optical.RearIllumination.Enable = 0;
Optical.RearIllumination.Spectrum.Type = 'AM1.5g';
Optical.RearIllumination.Scale = 1;

Optical.TextZ.FrontText.Type = 'from Rtot'; % Text of front side is determined from rear Rtot measurement, settingsgroup Optical.TextZ.FrontRtot
Optical.TextZ.FrontText.IncludeShading = 1;
Optical.TextZ.FrontText.FacetAngle = 54;
Optical.TextZ.FrontText.Aext.Type = 'file';
Optical.TextZ.FrontText.Aext.File = 'front_Aext.csv';
Optical.TextZ.FrontRtot.Type = 'file';
Optical.TextZ.FrontRtot.File = 'front_Rtot.csv';
Optical.TextZ.FrontRtot.MetalCorrection = 1; % measurement was between fingers
Optical.TextZ.FrontRtot.SampleThickness = 160 um; % the smaple thickness of the measurement of R
Optical.TextZ.FrontRtot.SampleTemperature = 20 degC; % the temperature during the measurement of R

Optical.TextZ.RearText.Type = 'from Rtot'; % Text of rear side is determined from rear Rtot measurement, settingsgroup Optical.TextZ.RearRtot
Optical.TextZ.RearText.IncludeShading = 1;
Optical.TextZ.RearText.FacetAngle = 0; % planarized rear surface
Optical.TextZ.RearText.Aext.Type = 'file';
Optical.TextZ.RearText.Aext.File = 'rear_Aext.csv';
Optical.TextZ.RearRtot.Type = 'file';
Optical.TextZ.RearRtot.File = 'rear_Rtot.csv';
Optical.TextZ.RearRtot.MetalCorrection = 1;
Optical.TextZ.RearRtot.SampleThickness = 160 um;
Optical.TextZ.RearRtot.SampleTemperature = 20 degC;

Optical.TextZ.FrontZ.Type = 'local'; % 'local' means that light-trapping is modelled via the internal optical properties of the skins
Optical.TextZ.RearZ.Type = 'local';

Optical.ScaleGeneration = 1;

Bulk.BackgroundDoping.SettingType = 'dopingtype-resistivity';
Bulk.BackgroundDoping.DopingType = 'n-type';
Bulk.BackgroundDoping.Resistivity = 1.3;

SkinFeature(1).Name = 'front skin';
SkinFeature(1).Geometry.Plane = 'front';
SkinFeature(1).OpticalModelType = 'lumped';
SkinFeature(1).Lumped.Optical.Internal.Rint = 0.92;
SkinFeature(1).Lumped.Optical.Internal.Diffuse = 1;
SkinFeature(1).Lumped.Optical.Internal.Appp = 0.01;

SkinFeature(2).Name = 'rear skin';
SkinFeature(2).Geometry.Plane = 'rear';
SkinFeature(2).OpticalModelType = 'lumped';
SkinFeature(2).Lumped.Optical.Internal.Rint = 0.92;
SkinFeature(2).Lumped.Optical.Internal.Diffuse = 1;
SkinFeature(2).Lumped.Optical.Internal.Appp = 0.01;

Sweep.Enable = 1;
Sweep.NGroups = 1;
Sweep.GroupA(1).Parameter = 'Optical.FrontIllumination.Enable';
Sweep.GroupA(1).Values = [1 0];
Sweep.GroupA(2).Parameter = 'Optical.RearIllumination.Enable';
Sweep.GroupA(2).Values = [0 1];


Optim.Enable = 1;

% first define which are the fit parameters, and set sensible bounds
Optim.Variable(1).Parameter = 'SkinFeature(1).Lumped.Optical.Internal.Appp';
Optim.Variable(1).Guess = 0.01;
Optim.Variable(1).UpperBound = 0.1;
Optim.Variable(1).LowerBound = 0.001;
Optim.Variable(1).Link(1).Parameter = 'SkinFeature(2).Lumped.Optical.Internal.Appp';
Optim.Variable(2).Parameter = 'SkinFeature(1).Lumped.Optical.Internal.Rint';
Optim.Variable(2).Guess = 0.9;
Optim.Variable(2).UpperBound = 1; % Lambertian limit
Optim.Variable(2).LowerBound = 0.5;
Optim.Variable(3).Parameter = 'SkinFeature(2).Lumped.Optical.Internal.Rint';
Optim.Variable(3).Guess = 0.9;
Optim.Variable(3).UpperBound = 1;
Optim.Variable(3).LowerBound = 0.5;
% Optim.Variable(4).Parameter = 'SkinFeature(2).Lumped.Optical.Internal.Appp';
% Optim.Variable(4).Guess = 0.01;
% Optim.Variable(4).UpperBound = 0.1;
% Optim.Variable(4).LowerBound = 0.001;

% first curve to fit: reflection for front illumination
Optim.Goal(1).Type = 'curve';
Optim.Goal(1).XResultName = '/Curves/wavelength';
Optim.Goal(1).YResultName = '/Curves/Rtot';
Optim.Goal(1).iSweepA = 1; % first sweep point is front illumination
Optim.Goal(1).Curve.Type = 'file';
Optim.Goal(1).Curve.File = 'front_Rtot.csv';
Optim.Goal(1).CurveRange.Enable = 1;
Optim.Goal(1).CurveRange.Xmin = 900;
Optim.Goal(1).CurveRange.Xmax = 1200;

% second curve to fit: reflection for rear illumination
Optim.Goal(2).Type = 'curve';
Optim.Goal(2).XResultName = '/Curves/wavelength';
Optim.Goal(2).YResultName = '/Curves/Rtot';
Optim.Goal(2).iSweepA = 2;
Optim.Goal(2).Curve.Type = 'file';
Optim.Goal(2).Curve.File = 'rear_Rtot.csv';
Optim.Goal(2).CurveRange.Enable = 1;
Optim.Goal(2).CurveRange.Xmin = 900;
Optim.Goal(2).CurveRange.Xmax = 1200;

% optional third curve to fit: EQE = Abb (band-to-band absorption) for front illumination
Optim.Goal(3).Type = 'curve';
Optim.Goal(3).XResultName = '/Curves/wavelength';
Optim.Goal(3).YResultName = '/Curves/AbbBulk';
Optim.Goal(3).iSweepA = 1; % first sweep point is front illumination
Optim.Goal(3).Curve.Type = 'file';
Optim.Goal(3).Curve.File = 'front_Abb.csv';
Optim.Goal(3).CurveRange.Enable = 1;
Optim.Goal(3).CurveRange.Xmin = 900;
Optim.Goal(3).CurveRange.Xmax = 1200;

% optional fourth curve to fit: EQE = Abb (band-to-band absorption) for rear illumination
Optim.Goal(4).Type = 'curve';
Optim.Goal(4).XResultName = '/Curves/wavelength';
Optim.Goal(4).YResultName = '/Curves/AbbBulk';
Optim.Goal(4).iSweepA = 2;
Optim.Goal(4).Curve.Type = 'file';
Optim.Goal(4).Curve.File = 'rear_Abb.csv';
Optim.Goal(4).CurveRange.Enable = 1;
Optim.Goal(4).CurveRange.Xmin = 900;
Optim.Goal(4).CurveRange.Xmax = 1200;